@@ -3,13 +3,14 @@ from famodels.models.trading_signal import TradingSignal
 from famodels.models.state_of_signal import StateOfSignal
 
 class ProcessedTradingSignal(TradingSignal):
-    """As soon a Signal is process by the signal qualifier, it is declared as a Processed Signal."""
+    """As soon a Signal is processed by the signal qualifier, it is declared as a Processed Signal."""
 
-    def __init__(self, signal: TradingSignal, status: StateOfSignal = None, process_info: List[str] = None):
+    def __init__(self, signal: TradingSignal, status: StateOfSignal, process_info: List = None):
+        self.status: StateOfSignal = status
         super().__init__(
             id=signal.id,
-            supplier_correlation_id=signal.supplier_correlation_id,
-            trade_correlation_id=signal.trade_correlation_id,
+            supplier_correlation_id=signal.provider_signal_id,
+            trade_correlation_id=signal.provider_trade_id,
             is_hot_signal=signal.is_hot_signal,
             algo_id=signal.algo_id,
             provider_id=signal.provider_id,
@@ -23,8 +24,7 @@ class ProcessedTradingSignal(TradingSignal):
             timestamp_of_creation=signal.timestamp_of_creation,
             timestamp_of_registration=signal.timestamp_of_registration,
             position_size_of_investment=signal.position_size_of_investment
-        )
-        self.status: StateOfSignal = status
+        )        
         self.process_info: List[str] = process_info
         
 
